macro_rules! span_err {
($($arg:tt)*) => { ... };
}Expand description
Sets the current span status to error with a formatted message.
Use this to mark the current span as failed with a descriptive error message.
Note: execution will continue after this macro has been called.
Examples
use apollo_opentelemetry::{span, span_err};
fn process(id: u64) {
span!("process", || {
span_err!("failed to process id {}", id);
});
}